@@ -1,3 +1,5 @@
+-- CopyRight(c) pgRouting developers
+-- Creative Commons Attribution-Share Alike 3.0 License : https://creativecommons.org/licenses/by-sa/3.0/
 /* -- q2 */
 SELECT * FROM pgr_bdAstarCostMatrix(
   'SELECT id, source, target, cost, reverse_cost, x1, y1, x2, y2 FROM edges',
@@ -12,7 +14,6 @@ SELECT * FROM pgr_TSP(
     (SELECT array_agg(id) FROM vertices WHERE id IN (5, 6, 10, 15)),
     directed=> false, heuristic => 2
   )
-  $$,
-  randomize => false
+  $$
 );
 /* -- q4 */
