@@ -1,24 +1,26 @@
+-- CopyRight(c) pgRouting developers
+-- Creative Commons Attribution-Share Alike 3.0 License : https://creativecommons.org/licenses/by-sa/3.0/
 /* -- q1 */
 SELECT * FROM pgr_turnRestrictedPath(
   $$SELECT id, source, target, cost, reverse_cost FROM edges$$,
-  $$SELECT path, cost FROM new_restrictions$$,
+  $$SELECT path, cost FROM restrictions$$,
   3, 8, 3);
 /* -- q2 */
 SELECT * FROM pgr_turnRestrictedPath(
   $$SELECT id, source, target, cost, reverse_cost FROM edges$$,
-  $$SELECT path, cost FROM new_restrictions$$,
+  $$SELECT path, cost FROM restrictions$$,
   3, 8, 3,
   strict => true);
 /* -- q3 */
 SELECT * FROM pgr_turnRestrictedPath(
   $$SELECT id, source, target, cost, reverse_cost FROM edges$$,
-  $$SELECT path, cost FROM new_restrictions$$,
+  $$SELECT path, cost FROM restrictions$$,
   3, 8, 3,
   directed => false);
 /* -- q4 */
 SELECT * FROM pgr_turnRestrictedPath(
   $$SELECT id, source, target, cost, reverse_cost FROM edges$$,
-  $$SELECT path, cost FROM new_restrictions$$,
+  $$SELECT path, cost FROM restrictions$$,
   3, 8, 3,
   directed => false,
   heap_paths => true,
