@@ -1,3 +1,5 @@
+-- CopyRight(c) pgRouting developers
+-- Creative Commons Attribution-Share Alike 3.0 License : https://creativecommons.org/licenses/by-sa/3.0/
 SET extra_float_digits=-3;
 /* -- q2 */
 SELECT * FROM pgr_withPointsDD(
@@ -21,3 +23,15 @@ SELECT * FROM pgr_withPointsDD(
   driving_side => 'b',
   details => true);
 /* -- q5 */
+SELECT * FROM pgr_withPointsDD(
+  $e$ SELECT * FROM edges $e$,
+  $p$ SELECT edge_id, round(fraction::numeric, 2) AS fraction, side
+      FROM pgr_findCloseEdges(
+        $$SELECT id, geom FROM edges$$,
+        (SELECT ST_POINT(2.9, 1.8)),
+        0.5, cap => 2)
+  $p$,
+  ARRAY[-1, -2], 2.3,
+  driving_side => 'r',
+  details => true);
+/* -- q6 */
