@@ -1,3 +1,5 @@
+-- CopyRight(c) pgRouting developers
+-- Creative Commons Attribution-Share Alike 3.0 License : https://creativecommons.org/licenses/by-sa/3.0/
 SET extra_float_digits=-3;
 /* --q1 */
 SELECT * FROM pgr_withPointsKSP(
@@ -17,3 +19,14 @@ SELECT * FROM pgr_withPointsKSP(
     -1, -2, 2,
     heap_paths := true, driving_side := 'r', details := true);
 /* --q4 */
+SELECT * FROM pgr_withPointsKSP(
+  $e$ SELECT * FROM edges $e$,
+  $p$ SELECT edge_id, round(fraction::numeric, 2) AS fraction, side
+      FROM pgr_findCloseEdges(
+        $$SELECT id, geom FROM edges$$,
+        (SELECT ST_POINT(2.9, 1.8)),
+        0.5, cap => 2)
+  $p$,
+  1, -1, 2,
+  driving_side := 'r');
+/* -- q5 */
