@@ -27,7 +27,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 /* for size-t */
 #include <stddef.h>
-#include "c_types/pgr_combination_t.h"
+typedef struct II_t_rt II_t_rt;
 
 
 /*! @brief combinations_sql
@@ -44,7 +44,7 @@ FROM combinations_table;
 */
 void pgr_get_combinations(
         char *combinations_sql,
-        pgr_combination_t **combinations,
+        II_t_rt **combinations,
         size_t *total_combinations);
 
 #endif  // INCLUDE_C_COMMON_COMBINATIONS_INPUT_H_
