@@ -20,49 +20,26 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-********************************************************************PGR-GNU*/
+ ********************************************************************PGR-GNU*/
 /*! @file */
 
 #ifndef INCLUDE_C_TYPES_POINT_ON_EDGE_T_H_
 #define INCLUDE_C_TYPES_POINT_ON_EDGE_T_H_
 #pragma once
 
+/* for int64_t */
 #ifdef __cplusplus
-
-#include <cstddef>
-
-#else  // __cplusplus
-
-// for bool
-#ifdef __GNUC__
-#if __GNUC__ > 5
-#pragma GCC diagnostic ignored "-Wpedantic"
+#   include <cstdint>
 #else
-#pragma GCC diagnostic ignored "-pedantic"
-#endif
+#   include <stdint.h>
 #endif
 
-#include <postgres.h>
-
-#ifdef __GNUC__
-#pragma GCC diagnostic pop
-#endif
-
-// For NULL & size_t
-#include <stdlib.h>
-
-
-#endif  // __cplusplus
-
-// For int64_t etc
-#include <stdint.h>
-
-typedef struct {
+struct Point_on_edge_t {
     int64_t pid;
     int64_t edge_id;
     char side;  // 'r', 'l', 'b' (default is both)
     double fraction;
     int64_t vertex_id;  // number is negative and is used for processing
-} Point_on_edge_t;
+};
 
 #endif  // INCLUDE_C_TYPES_POINT_ON_EDGE_T_H_
