@@ -10,6 +10,10 @@ Copyright (c) 2020 The combinations_sql signature is added by Mahmoud SAKR
 and Esteban ZIMANYI
 mail: m_attia_sakr@yahoo.com, estebanzimanyi@gmail.com
 
+Copyright (c) 2022 Celia Virginia Vergara Castillo
+* Added 1 to many with set parameter
+* Added dijkstra with a map of combinations
+
 ------
 
 This program is free software; you can redistribute it and/or modify
@@ -32,10 +36,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #define INCLUDE_DIJKSTRA_PGR_DIJKSTRA_HPP_
 #pragma once
 
-#include <boost/config.hpp>
-#include <boost/graph/adjacency_list.hpp>
-#include <boost/graph/dijkstra_shortest_paths.hpp>
-
 #include <deque>
 #include <set>
 #include <vector>
@@ -46,16 +46,16 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <map>
 #include <numeric>
 
+#include <boost/config.hpp>
+#include <boost/graph/adjacency_list.hpp>
+#include <boost/graph/dijkstra_shortest_paths.hpp>
+
 #include "c_types/ii_t_rt.h"
 #include "cpp_common/basePath_SSEC.hpp"
 #include "cpp_common/pgr_base_graph.hpp"
 #include "cpp_common/interruption.h"
 #include "visitors/dijkstra_one_goal_visitor.hpp"
 
-#if 0
-#include "./../../common/src/signalhandler.h"
-#endif
-
 namespace pgrouting {
 
 template < class G > class Pgr_dijkstra;
@@ -203,9 +203,39 @@ class Pgr_dijkstra {
      }
 
 
+     //! Dijkstra 1 to many
+     std::deque<Path> dijkstra(
+             G &graph,
+             int64_t start_vertex,
+             const std::set<int64_t> &end_vertex,
+             bool only_cost,
+             size_t n_goals) {
+         clear();
 
+         predecessors.resize(graph.num_vertices());
+         distances.resize(
+                 graph.num_vertices(),
+                 std::numeric_limits<double>::infinity());
 
+         if (!graph.has_vertex(start_vertex)) return std::deque<Path>();
 
+         auto v_source(graph.get_V(start_vertex));
+
+         std::set<V> s_v_targets;
+         for (const auto &vertex : end_vertex) {
+             if (graph.has_vertex(vertex)) s_v_targets.insert(graph.get_V(vertex));
+         }
+
+         std::vector<V> v_targets(s_v_targets.begin(), s_v_targets.end());
+         // perform the algorithm
+         dijkstra_1_to_many(graph, v_source, v_targets, n_goals);
+
+         std::deque<Path> paths;
+         // get the results
+         paths = get_paths(graph, v_source, v_targets, only_cost);
+
+         return paths;
+     }
 
      //! Dijkstra 1 to many
      std::deque<Path> dijkstra(
@@ -318,6 +348,25 @@ class Pgr_dijkstra {
         return paths;
     }
 
+    // dijkstra with a map of combinations
+    std::deque<Path> dijkstra(
+            G &graph,
+            const std::map<int64_t, std::set<int64_t>> &combinations,
+            bool only_cost,
+            size_t n_goals) {
+        std::deque<Path> paths;
+
+        for (const auto &c : combinations) {
+            auto r_paths = dijkstra(
+                    graph,
+                    c.first, c.second,
+                    only_cost, n_goals);
+            paths.insert(paths.begin(), r_paths.begin(), r_paths.end());
+        }
+
+        return paths;
+    }
+
      //@}
 
  private:
