@@ -41,14 +41,14 @@ using pgrouting::yen::Pgr_ksp;
 
 
 void  do_pgr_ksp(
-        pgr_edge_t *data_edges,
+        Edge_t *data_edges,
         size_t total_edges,
         int64_t  start_vid,
         int64_t  end_vid,
         size_t k,
         bool directed,
         bool heap_paths,
-        General_path_element_t **return_tuples,
+        Path_rt **return_tuples,
         size_t *return_count,
         char ** log_msg,
         char ** notice_msg,
