@@ -27,19 +27,27 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 #include "drivers/trsp/trsp_driver.h"
 
+#include <utility>
 #include <vector>
 #include <cstdint>
 #include <sstream>
 #include <deque>
 #include <algorithm>
+#include <limits>
 #include <set>
 #include <map>
+#include <cassert>
 
 #include "trsp/pgr_trspHandler.h"
 #include "cpp_common/rule.h"
 #include "cpp_common/pgr_assert.h"
 #include "cpp_common/pgr_alloc.hpp"
+#include "cpp_common/combinations.h"
 #include "c_types/restriction_t.h"
+#include "c_types/ii_t_rt.h"
+#include "dijkstra/pgr_dijkstra.hpp"
+#include "withPoints/pgr_withPoints.hpp"
+
 
 namespace {
 
@@ -66,39 +74,90 @@ post_process_trsp(std::deque<Path> &paths, bool sort) {
     }
 }
 
+template <class G>
+std::deque<Path>
+pgr_dijkstra(
+        G &graph,
+        std::map<int64_t, std::set<int64_t>> &combinations
+        ) {
+    pgrouting::Pgr_dijkstra<G> fn_dijkstra;
+    auto paths = fn_dijkstra.dijkstra(
+            graph,
+            combinations,
+            false, (std::numeric_limits<size_t>::max)());
+
+    return paths;
+}
+
 }  // namespace
 
 void
 do_trsp(
-        Edge_t *edges,
-        size_t total_edges,
+        Edge_t *edges, size_t total_edges,
+        Restriction_t *restrictions, size_t restrictions_size,
 
-        Restriction_t *restrictions,
-        size_t restrictions_size,
-
-        int64_t  *start_vidsArr,
-        size_t size_start_vidsArr,
-
-        int64_t  *end_vidsArr,
-        size_t size_end_vidsArr,
+        II_t_rt *combinations_arr, size_t total_combinations,
+        int64_t *starts_arr, size_t size_starts_arr,
+        int64_t *ends_arr, size_t size_ends_arr,
 
         bool directed,
 
-        Path_rt **return_tuples,
-        size_t *return_count,
-        char **log_msg,
-        char **notice_msg,
-        char **err_msg) {
+        Path_rt **return_tuples, size_t *return_count,
+
+        char** log_msg,
+        char** notice_msg,
+        char** err_msg) {
     std::ostringstream log;
-    std::ostringstream err;
     std::ostringstream notice;
+    std::ostringstream err;
     try {
         pgassert(edges);
-        pgassert(*return_tuples == NULL);
+        pgassert(!(*log_msg));
+        pgassert(!(*notice_msg));
+        pgassert(!(*err_msg));
+        pgassert(!(*return_tuples));
         pgassert(*return_count == 0);
-        pgassert(*log_msg == NULL);
-        pgassert(*notice_msg == NULL);
-        pgassert(*err_msg == NULL);
+
+        graphType gType = directed? DIRECTED: UNDIRECTED;
+
+        auto vertices(pgrouting::extract_vertices(edges, total_edges));
+
+        auto combinations = total_combinations?
+            pgrouting::utilities::get_combinations(combinations_arr, total_combinations)
+            : pgrouting::utilities::get_combinations(starts_arr, size_starts_arr, ends_arr, size_ends_arr);
+
+        std::deque<Path> paths;
+        if (directed) {
+            pgrouting::DirectedGraph digraph(vertices, gType);
+            digraph.insert_edges(edges, total_edges);
+
+            paths = pgr_dijkstra(
+                    digraph,
+                    combinations);
+        } else {
+            pgrouting::UndirectedGraph undigraph(vertices, gType);
+            undigraph.insert_edges(edges, total_edges);
+
+            paths = pgr_dijkstra(
+                    undigraph,
+                    combinations);
+        }
+
+        post_process_trsp(paths, false);
+        size_t count(0);
+        count = count_tuples(paths);
+
+        if (count == 0) {
+            notice << "No paths found";
+            *log_msg = pgr_msg(notice.str().c_str());
+            return;
+        }
+
+        if (restrictions_size == 0) {
+            (*return_tuples) = pgr_alloc(count, (*return_tuples));
+            (*return_count) = (collapse_paths(return_tuples, paths));
+            return;
+        }
 
         /*
          * When there are turn restrictions
@@ -109,23 +168,20 @@ do_trsp(
             ruleList.push_back(pgrouting::trsp::Rule(*(restrictions + i)));
         }
 
-        std::map<int64_t, std::set<int64_t>> combinations;
+        auto new_combinations = pgrouting::utilities::get_combinations(paths, ruleList);
 
-        for (size_t i = 0; i < size_start_vidsArr; ++i) {
-            for (size_t j = 0; j < size_end_vidsArr; ++j) {
-                combinations[start_vidsArr[i]].insert(end_vidsArr[j]);
-            }
+        if (!new_combinations.empty()) {
+            pgrouting::trsp::Pgr_trspHandler gdef(
+                    edges,
+                    total_edges,
+                    directed,
+                    ruleList);
+            auto new_paths = gdef.process(new_combinations);
+            paths.insert(paths.end(), new_paths.begin(), new_paths.end());
         }
-
-        pgrouting::trsp::Pgr_trspHandler gdef(
-                edges,
-                total_edges,
-                directed,
-                ruleList);
-        auto paths = gdef.process(combinations);
         post_process_trsp(paths, true);
 
-        auto count = count_tuples(paths);
+        count = count_tuples(paths);
 
         if (count == 0) {
             (*return_tuples) = NULL;
