@@ -10,20 +10,18 @@ CREATE TABLE solomon_100_RC_101 (
     y float8
 );
 
-COPY solomon_100_RC_101
-(id, x, y, order_unit, open_time, close_time, service_time) FROM stdin;
-1	40.000000	50.000000	0	0	240	0
-2	25.000000	85.000000	20	145	175	10
-3	22.000000	75.000000	30	50	80	10
-4	22.000000	85.000000	10	109	139	10
-5	20.000000	80.000000	40	141	171	10
-6	20.000000	85.000000	20	41	71	10
-7	18.000000	75.000000	20	95	125	10
-8	15.000000	75.000000	20	79	109	10
-9	15.000000	80.000000	10	91	121	10
-10	10.000000	35.000000	20	91	121	10
-11	10.000000	40.000000	30	119	149	10
-\.
+INSERT INTO solomon_100_RC_101 (id, x, y, order_unit, open_time, close_time, service_time) VALUES
+(1, 40.000000, 50.000000, 0, 0, 240, 0),
+(2, 25.000000, 85.000000, 20, 145, 175, 10),
+(3, 22.000000, 75.000000, 30, 50, 80, 10),
+(4, 22.000000, 85.000000, 10, 109, 139, 10),
+(5, 20.000000, 80.000000, 40, 141, 171, 10),
+(6, 20.000000, 85.000000, 20, 41, 71, 10),
+(7, 18.000000, 75.000000, 20, 95, 125, 10),
+(8, 15.000000, 75.000000, 20, 79, 109, 10),
+(9, 15.000000, 80.000000, 10, 91, 121, 10),
+(10, 10.000000, 35.000000, 20, 91, 121, 10),
+(11, 10.000000, 40.000000, 30, 119, 149, 10);
 
 DROP TABLE IF EXISTS vrp_vehicles cascade;
 CREATE TABLE vrp_vehicles (
@@ -32,11 +30,10 @@ CREATE TABLE vrp_vehicles (
     case_no integer
 );
 
-copy vrp_vehicles (vehicle_id, capacity, case_no) from stdin;
-1	200	5
-2	200	5
-3	200	5
-\.
+INSERT INTO vrp_vehicles (vehicle_id, capacity, case_no) VALUES
+(1, 200, 5),
+(2, 200, 5),
+(3, 200, 5);
 
 DROP TABLE IF EXISTS vrp_distance cascade;
 WITH
